OC.L10N.register(
    "settings",
    {
    "Private" : "Privat",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Nur sichtbar für Personen, die über Rufnummernintegration von Talk on mobile abgeglichen wurden.",
    "Local" : "Lokal",
    "Only visible to people on this instance and guests" : "Nur für Personen dieser Instanz und Gästen sichtbar",
    "Federated" : "Federated",
    "Only synchronize to trusted servers" : "Nur mit vertrauenswürdigen Servern synchronisieren",
    "Published" : "Veröffentlicht",
    "Synchronize to trusted servers and the global and public address book" : "Mit vertrauenswürdigen Servern und dem globalen und öffentlichen Adressbuch synchronisieren",
    "Verify" : "Überprüfen",
    "Verifying …" : "Überprüfe…",
    "Unable to change password" : "Passwort konnte nicht geändert werden",
    "Very weak password" : "Sehr schwaches Passwort",
    "Weak password" : "Schwaches Passwort",
    "So-so password" : "Akzeptables Passwort",
    "Good password" : "Gutes Passwort",
    "Strong password" : "Starkes Passwort",
    "Groups" : "Gruppen",
    "Group list is empty" : "Gruppenliste ist leer",
    "Unable to retrieve the group list" : "Gruppenliste konnte nicht abgerufen werden",
    "{actor} added you to group {group}" : "{actor} hat Sie zur Gruppe {group} hinzugefügt",
    "You added {user} to group {group}" : "Sie haben {user} zur Gruppe {group} hinzugefügt",
    "{actor} added {user} to group {group}" : "{actor} hat {user} zur Gruppe {group} hinzugefügt",
    "An administrator added you to group {group}" : "Ein Administrator hat Sie zur Gruppe {group} hinzugefügt",
    "An administrator added {user} to group {group}" : "Ein Administrator hat {user} zur Gruppe {group} hinzugefügt",
    "{actor} removed you from group {group}" : "{actor} hat Sie von der Gruppe {group} entfernt",
    "You removed {user} from group {group}" : "Sie haben {user} von der Gruppe {group} entfernt",
    "{actor} removed {user} from group {group}" : "{actor} hat {user} von der Gruppe {group} entfernt",
    "An administrator removed you from group {group}" : "Ein Administrator hat Sie von der Gruppe {group} entfernt",
    "An administrator removed {user} from group {group}" : "Ein Administrator hat {user} von der Gruppe {group} entfernt",
    "Your <strong>group memberships</strong> were modified" : "Ihre <strong>Gruppenmitgliedschaft</strong> wurde geändert",
    "{actor} changed your password" : "{actor} hat Ihr Passwort geändert",
    "You changed your password" : "Sie haben Ihr Passwort geändert",
    "Your password was reset by an administrator" : "Ihr Passwort wurde von der Administration zurückgesetzt",
    "Your password was reset" : "Ihr Passwort wurde zurückgesetzt",
    "{actor} changed your email address" : "{actor} hat Ihre E-Mail-Adresse geändert",
    "You changed your email address" : "Sie haben Ihre E-Mail-Adresse geändert",
    "Your email address was changed by an administrator" : "Ihre E-Mail-Adresse wurde von einem Administrator geändert",
    "You created an app password for a session named \"{token}\"" : "Sie haben ein App-Passwort für eine Sitzung mit dem Namen \"{token}\" erstellt",
    "An administrator created an app password for a session named \"{token}\"" : "Die Administration hat ein App-Passwort für eine Sitzung mit dem Namen \"{token}“ erstellt",
    "You deleted app password \"{token}\"" : "Sie haben das App-Passwort \"{token}\" entfernt",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Sie haben das App-Passwort \"{token}\" in \"{newToken}\" umbenannt",
    "You granted filesystem access to app password \"{token}\"" : "Sie haben Dateisystemzugriff für App-Passwort \"{token}\" erlaubt",
    "You revoked filesystem access from app password \"{token}\"" : "Sie haben Dateisystemzugriff für App-Passwort \"{token}\" widerrufen",
    "Security" : "Sicherheit",
    "You successfully logged in using two-factor authentication (%1$s)" : "Sie haben sich erfolgreich mittels Zwei-Faktor-Authentifizierung angemeldet (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Ein Anmeldeversuch mittels Zwei-Faktor-Authentifizierung schlug fehl (%1$s)",
    "Remote wipe was started on %1$s" : "Fernlöschung wurde am %1$s gestartet",
    "Remote wipe has finished on %1$s" : "Fernlöschung wurde am %1$s abgeschlossen",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Ihr <strong>Passwort</strong> oder Ihre <strong>E-Mail-Adresse</strong> wurde geändert",
    "Apps" : "Apps",
    "Could not remove app." : "App konnte nicht entfernt werden.",
    "Could not update app." : "App konnte nicht aktualisiert werden.",
    "Wrong password" : "Falsches Passwort",
    "Unable to change personal password" : "Das persönliche Passwort konnte nicht geändert werden",
    "Saved" : "Gespeichert",
    "No user supplied" : "Kein Benutzer angegeben",
    "Unable to change password. Password too long." : "Passwort konnte nicht geändert werden. Passwort ist zu lang.",
    "Authentication error" : "Authentifizierungsfehler",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Bitte geben Sie ein Wiederherstellungspasswort für das Administrationskonto an, da sonst alle Benutzerdaten verlorengehen.",
    "Wrong admin recovery password. Please check the password and try again." : "Falsches Wiederherstellungspasswort für das Admin-Konto. Bitte überprüfen Sie das Passwort und versuchen Sie es erneut.",
    "Backend does not support password change, but the user's encryption key was updated." : "Das Backend unterstützt die Passwortänderung nicht, aber das Verschlüsselungspasswort des Benutzers wurde aktualisiert.",
    "installing and updating apps via the App Store or Federated Cloud Sharing" : "Das Installieren und Aktualisieren von Apps durch den App-Store oder durch Federated-Cloud-Sharing",
    "Federated Cloud Sharing" : "Federated-Cloud-Sharing",
    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL verwendet eine veraltete %1$s Version (%2$s). Bitte aktualisieren Sie Ihr Betriebssystem, da ansonsten Funktionen wie z.B. %3$s nicht zuverlässig funktionieren.",
    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the Nextcloud log file for more details." : "Es konnte nicht festgestellt werden, ob die TLS-Version von cURL veraltet ist oder nicht, da während der HTTPS-Anforderung an https://nextcloud.com ein Fehler aufgetreten ist. Bitte überprüfen Sie die Nextcloud-Protokolldatei für weitere Einzelheiten.",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "Das PHP-OPcache-Modul ist nicht geladen. Für eine bessere Leistung empfiehlt es sich, das Modul in Ihre PHP-Installation zu laden.",
    "OPcache is disabled. For better performance, it is recommended to apply <code>opcache.enable=1</code> to your PHP configuration." : "OPcache ist deaktiviert. Für eine bessere Leistung wird empfohlen, <code>opcache.enable=1</code> auf Ihre PHP-Konfiguration anzuwenden.",
    "OPcache is configured to remove code comments. With OPcache enabled, <code>opcache.save_comments=1</code> must be set for Nextcloud to function." : "OPcache ist so konfiguriert, dass Codekommentare entfernt werden. Wenn OPcache aktiviert ist, muss <code>opcache.save_comments=1</code> gesetzt werden, damit Nextcloud funktioniert.",
    "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud darf die OPcache-API nicht verwenden. Wenn OPcache aktiviert ist, wird dringend empfohlen, alle Nextcloud-Verzeichnisse mit <code>opcache.restrict_api</code> einzuschließen oder diese Einstellung zu deaktivieren, um OPcache-API-Einschränkungen zu deaktivieren und Fehler während Nextcloud-Core- oder App-Aktualisierungen zu vermeiden.",
    "Nextcloud is not allowed to use the OPcache API. It is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud darf die OPcache-API nicht verwenden. Es wird dringend empfohlen, alle Nextcloud-Verzeichnisse mit <code>opcache.restrict_api</code> einzuschließen oder diese Einstellung zu deaktivieren, um OPcache-API-Einschränkungen zu deaktivieren und Fehler während Nextcloud-Core- oder App-Aktualisierungen zu vermeiden.",
    "The shared memory based OPcache is disabled. For better performance, it is recommended to apply <code>opcache.file_cache_only=0</code> to your PHP configuration and use the file cache as second level cache only." : "Der OPcache mit gemeinsamem Speicher ist deaktiviert. Für eine bessere Leistung wird empfohlen, opcache.file_cache_only=0 in Ihre PHP-Konfiguration aufzunehmen und den Dateicache nur als Second Level Cache zu verwenden.",
    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "Die maximale Anzahl von OPcache-Schlüsseln ist fast erreicht. Um sicherzustellen, dass alle Skripte im Cache gehalten werden können, wird empfohlen, <code>opcache.max_accelerated_files</code> mit einem höheren Wert als <code>%s</code> in Ihrer PHP-Konfiguration anzuwenden.",
    "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.memory_consumption</code> to your PHP configuration with a value higher than <code>%s</code>." : "Der OPcache-Puffer ist fast voll. Um sicherzustellen, dass alle Skripte im Cache gehalten werden können, wird empfohlen, <code>opcache.memory_consumption</code> auf Ihre PHP-Konfiguration mit einem höheren Wert als <code>%s</code> anzuwenden. ",
    "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply <code>opcache.interned_strings_buffer</code> to your PHP configuration with a value higher than <code>%s</code>." : "Der OPcache-Zwischenspeicher für interne Zeichenfolgen ist fast voll. Um sicherzustellen, dass sich wiederholende Zeichenfolgen effektiv zwischengespeichert werden können, wird empfohlen, <code>opcache.interned_strings_buffer</code> mit einem Wert größer als <code>%s</code> auf Ihre PHP-Konfiguration anzuwenden.",
    "Administrator documentation" : "Dokumentation für die Administration",
    "User documentation" : "Dokumentation für Benutzer",
    "Invalid SMTP password." : "Ungültiges SMTP-Passwort.",
    "Email setting test" : "Test der E-Mail-Einstellungen",
    "Well done, %s!" : "Gut gemacht, %s!",
    "If you received this email, the email configuration seems to be correct." : "Wenn Sie diese E-Mail empfangen haben, sind die E-Mail-Einstellungen korrekt.",
    "Email could not be sent. Check your mail server log" : "E-Mail konnte nicht versandt werden. Prüfen Sie Ihr E-Mail-Server-Protokoll",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Beim Senden der E-Mail ist ein Problem aufgetreten. Bitte überprüfen Sie Ihre Einstellungen. (Fehler: %s)",
    "You need to set your user email before being able to send test emails. Go to %s for that." : "Sie müssen Ihre Benutzer-E-Mail-Adresse festlegen, bevor Sie Test-E-Mails senden können. Gehen Sie dazu zu %s.",
    "Users" : "Benutzer",
    "Invalid user" : "Ungültiger Benutzer",
    "Invalid mail address" : "Ungültige E-Mail-Adresse",
    "Settings saved" : "Einstellungen gespeichert",
    "Unable to change full name" : "Der vollständige Name konnte nicht geändert werden",
    "Unable to change email address" : "E-Mail-Adresse konnte nicht geändert werden",
    "Unable to set invalid phone number" : "Ungültige Rufnummer kann nicht eingestellt werden",
    "Unable to set invalid website" : "Ungültige Webseite kann nicht eingestellt werden",
    "Some account data was invalid" : "Einige Kontodaten waren ungültig",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Um Ihr Twitter-Konto zu überprüfen, veröffentlichen Sie bitte den folgenden Tweet auf Twitter (Bitte stellen Sie sicher, dass der Tweet keinen Zeilenumbruch enthält):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Um Ihre Webseite zu überprüfen, speichern Sie bitte den folgenden Inhalt im Web-Wurzelverzeichnist in der Datei '.well-known/CloudIdVerificationCode.txt' (bitte stellen Sie sicher, das sich der gesamte Text in einer Zeile befindet):",
    "%1$s changed your password on %2$s." : "%1$s hat Ihr Passwort auf %2$s geändert.",
    "Your password on %s was changed." : "Ihr Passwort auf %s wurde geändert.",
    "Your password on %s was reset by an administrator." : "Ihr Passwort auf %s wurde vom Administrator zurückgesetzt.",
    "Your password on %s was reset." : "Ihr Passwort auf %s wurde zurückgesetzt",
    "Password for %1$s changed on %2$s" : "Passwort für %1$s geändert auf %2$s",
    "Password changed for %s" : "Passwort geändert für %s ",
    "If you did not request this, please contact an administrator." : "Wenn Sie das nicht angefordert haben sollten, wenden Sie sich bitte an den Administrator.",
    "Your email address on %s was changed." : "Ihre E-Mail-Adresse auf %s wurde geändert.",
    "Your email address on %s was changed by an administrator." : "Ihre E-Mail-Adresse auf %s wurde von der Administration geändert.",
    "Email address for %1$s changed on %2$s" : "E-Mail-Adresse für %1$s geändert auf %2$s",
    "Email address changed for %s" : "E-Mail-Adresse geändert für %s",
    "The new email address is %s" : "Die neue E-Mail-Adresse lautet %s",
    "Your %s account was created" : "Ihr %s-Konto wurde erstellt",
    "Welcome aboard" : "Willkommen an Bord",
    "Welcome aboard %s" : "Willkommen an Bord %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Willkommen zu Ihrem %s-Konto. Sie können Ihre Daten hinzufügen, schützen und teilen.",
    "Your username is: %s" : "Ihr Benutzername lautet: %s",
    "Set your password" : "Setzen Sie Ihr Passwort",
    "Go to %s" : "%s aufrufen",
    "Install Client" : "Installiere den Client",
    "Logged in user must be a subadmin" : "Der angemeldete Benutzer muss ein Subadministrator sein",
    "Settings" : "Einstellungen",
    "Personal" : "Persönlich",
    "Administration" : "Verwaltung",
    "Additional settings" : "Zusätzliche Einstellungen",
    "Administration privileges" : "Administratorrechte",
    "Groupware" : "Groupware",
    "Overview" : "Übersicht",
    "Basic settings" : "Grundeinstellungen",
    "Sharing" : "Teilen",
    "Availability" : "Verfügbarkeit",
    "Calendar" : "Kalender",
    "Personal info" : "Persönliche Informationen",
    "Mobile & desktop" : "Mobil & Desktop",
    "Email server" : "E-Mail-Server",
    "Security & setup warnings" : "Sicherheits- & Einrichtungswarnungen",
    "Background jobs" : "Hintergrund-Aufgaben",
    "Create" : "Erstellen",
    "Change" : "Ändern",
    "Delete" : "Löschen",
    "Reshare" : "Weiterteilen",
    "Unlimited" : "Unbegrenzt",
    "Verifying" : "Überprüfe",
    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Eine Hintergrundaufgabe, die nach vom Benutzer importierten SSL-Zertifikaten sucht, läuft noch. Bitte später erneut versuchen.",
    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Es sind einige vom Benutzer importierte SSL-Zertifikate vorhanden, die von Nextcloud 21 nicht mehr verwendet werden. Sie können über den Befehl \"occ security:certificates:import\" in der Befehlszeile importiert werden. Ihre Pfade innerhalb des Datenverzeichnisses werden unten angezeigt.",
    "Invalid UUIDs of LDAP users or groups have been found. Please review your \"Override UUID detection\" settings in the Expert part of the LDAP configuration and use \"occ ldap:update-uuid\" to update them." : "Es wurden ungültige UUIDs von LDAP-Benutzern oder -Gruppen gefunden. Bitte überprüfen Sie Ihre „UUID-Erkennung überschreiben“-Einstellungen im Expertenteil der LDAP-Konfiguration und verwenden Sie „occ ldap:update-uuid“, um sie zu aktualisieren.",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "Das alte serverseitige Verschlüsselungsformat ist aktiviert. Wir empfehlen, es zu deaktivieren.",
    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "MariaDB Version \"%s\" wird verwendet. Nextcloud 21 und neuer unterstützen diese Version nicht und benötigen MariaDB 10.2 oder neuer.",
    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "MySQL Version \"%s\" wird verwendet. Nextcloud 21 und neuer unterstützten diese Version nicht und benötigen MySQL 8.0 oder MariaDB 10.2 oder neuer.",
    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "PostgreSQL Version \"%s\" wird verwendet. Nextcloud 21 und neuer unterstützen diese Version nicht und beötigen PostgreSQL 9.6 oder neuer.",
    "Profile information" : "Profilinformation",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Profilbild, vollständiger Name, E-Mail-Adresse, Telefonnummer, Adresse, Webseite, Twitter, Organisation, Rolle, Überschrift, Biografie und ob Ihr Profil aktiviert ist",
    "Nextcloud settings" : "Nextcloud-Einstellungen",
    "Here you can decide which group can access certain sections of the administration settings." : "Hier können Sie festlegen, welche Gruppe auf bestimmte Bereiche der Administrationseinstellungen zugreifen kann.",
    "None" : "Keine",
    "Unable to modify setting" : "Einstellung konnte nicht geändert werden",
    "Two-Factor Authentication" : "Zwei-Faktor-Authentifizierung",
    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Zwei-Faktor-Authentifizierung kann für alle Benutzer und Gruppen erzwungen werden. Dann können Benutzer, für die keine Zwei-Faktor-Authentifizierung eingerichtet ist, sich nicht am System anmelden.",
    "Enforce two-factor authentication" : "Zwei-Faktor-Authentifizierung erzwingen",
    "Limit to groups" : "Auf Gruppen beschränken",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Erzwingen der Zwei-Faktor-Authentifizierung kann nur für bestimmte Gruppen eingestellt werden.",
    "Two-factor authentication is enforced for all members of the following groups." : "Zwei-Faktor-Authentifizierung wird für alle Mitglieder der folgenden Gruppen erzwungen.",
    "Enforced groups" : "Erzwungene Gruppen",
    "Two-factor authentication is not enforced for members of the following groups." : "Zwei-Faktor-Authentifizierung wird für Mitglieder der folgenden Gruppen nicht erzwungen.",
    "Excluded groups" : "Ausgeschlossene Gruppen",
    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Bei der Auswahl/Abwahl von Gruppen wird folgende Logik verwendet, um festzustellen, ob ein Benutzer 2FA verwenden muss: Wenn keine Gruppe ausgewählt ist, dann wird 2FA für alle Benutzer aktiviert, außer für Mitglieder der ausgenommenen Gruppen. Sind Gruppen ausgewählt, so wird 2FA für alle Mitglieder dieser Gruppen aktiviert. Ist ein Benutzer sowohl Mitglied der ausgewählten als auch der ausgenommenen Gruppe, so hat die Auswahl Vorrang und 2FA wird aktiviert. ",
    "Save changes" : "Änderungen speichern ",
    "All" : "Alle",
    "Limit app usage to groups" : "App-Verwendung auf Gruppen beschränken",
    "No results" : "Keine Ergebnisse",
    "Update to {version}" : "Aktualisieren auf {version}",
    "Remove" : "Entfernen",
    "Disable" : "Deaktivieren",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Für diese App wurde keine untere Versionsgrenze für Nextcloud gesetzt. Dies wird zukünftig als Fehler behandelt.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Für diese App wurde keine obere Versionsgrenze für Nextcloud gesetzt. Dies wird zukünftig als Fehler behandelt.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Diese App kann nicht installiert werden, weil die folgenden Abhängigkeiten nicht erfüllt sind:",
    "View in store" : "Im Store anzeigen",
    "Visit website" : "Webseite besuchen",
    "Report a bug" : "Einen technischen Fehler melden",
    "Admin documentation" : "Dokumentation für die Administration",
    "Developer documentation" : "Dokumentation für Entwickler",
    "This app is supported via your current Nextcloud subscription." : "Diese App wird von Ihrem aktuellen Nextcloud-Abonnement unterstützt.",
    "Supported" : "Unterstützt",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Vorgestellte Apps werden von und innerhalb der Nextcloud-Community entwickelt. Sie stellen zentrale Funktionen bereit und sind für den produktiven Einsatz geeignet.",
    "Featured" : "Vorgestellt",
    "Update to {update}" : "Aktualisieren auf {update}",
    "All apps are up-to-date." : "Alle Apps sind aktuell.",
    "Results from other categories" : "Ergebnisse aus anderen Kategorien",
    "No apps found for your version" : "Es wurden keine Apps für Ihre Version gefunden",
    "Disable all" : "Alle deaktivieren",
    "Enable all" : "Alle aktivieren",
    "_%n app has an update available_::_%n apps have an update available_" : ["Für %n App ist eine Aktualisierung verfügbar","Für %n Apps sind Aktualisierungen verfügbar"],
    "_Update_::_Update all_" : ["Aktualisieren","Alle aktualisieren"],
    "Marked for remote wipe" : "Für Fernlöschung markiert",
    "Device settings" : "Geräteeinstellungen",
    "Allow filesystem access" : "Erlaube Dateisystem-Zugriff",
    "Rename" : "Umbennen",
    "Revoke" : "Widerrufen",
    "Wipe device" : "Gerät löschen",
    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "Zurückziehen dieses Tokens könnte das Löschen von Ihrem Gerät verhindern, wenn die Löschung noch nicht gestartet wurde.",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome für Android",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "{productName} iOS app" : "{productName} iOS-App",
    "{productName} Android app" : "{productName} Android-App",
    "{productName} Talk for iOS" : "{productName} Talk für iOS",
    "{productName} Talk for Android" : "{productName} Talk für Android",
    "Sync client - {os}" : "Sync-Client - {os}",
    "This session" : "Diese Sitzung",
    "Device" : "Gerät",
    "Last activity" : "Letzte Aktivität",
    "Devices & sessions" : "Geräte & Sitzungen",
    "Web, desktop and mobile clients currently logged in to your account." : "Aktuell in Ihrem Konto angemeldete Web-, Desktop- und Mobil-Clients.",
    "Do you really want to wipe your data from this device?" : "Möchten Sie wirklich alle Daten von diesem Gerät löschen?",
    "Confirm wipe" : "Löschen bestätigen",
    "Error while creating device token" : "Fehler beim Erstellen des Geräte-Tokens",
    "Error while updating device token scope" : "Fehler bei der Aktualisierung des Geräte-Token-Scope",
    "Error while updating device token name" : "Fehler bei der Aktualisierung des Geräte-Token-Namens",
    "Error while deleting the token" : "Fehler beim Löschen des Geräte-Tokens",
    "Error while wiping the device with the token" : "Fehler während des Löschens des Geräts mit dem Token",
    "App name" : "App-Name",
    "Create new app password" : "Neues App-Passwort erstellen",
    "Use the credentials below to configure your app or device." : "Nutzen Sie die unten angebenen Anmeldeinformationen, um ihre App oder ihr Gerät zu konfigurieren.",
    "For security reasons this password will only be shown once." : "Aus Sicherheitsgründen wird das Passwort nur einmal angezeigt.",
    "Username" : "Benutzername",
    "Password" : "Passwort",
    "Done" : "Erledigt",
    "Show QR code for mobile apps" : "QR-Code für mobile Apps anzeigen",
    "Copied!" : "Kopiert!",
    "Copy" : "Kopieren",
    "Could not copy app password. Please copy it manually." : "Das Passwort für die App konnte nicht kopiert werden. Bitte kopieren Sie es manuell.",
    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "Damit der Server ordnungsgemäß funktioniert, ist es wichtig, Hintergrundjobs richtig zu konfigurieren. Cron ist die empfohlene Einstellung. Weitere Informationen finden Sie in der Dokumentation.",
    "Last job execution ran {time}. Something seems wrong." : "Die letzte Aufgaben-Ausführung lief {time}. Etwas scheint falsch zu sein.",
    "Last job ran {relativeTime}." : "Die letzte Aufgabe lief {relativeTime}.",
    "Background job did not run yet!" : "Hintergrund-Aufgabe wurde bislang nicht ausgeführt!",
    "AJAX" : "AJAX",
    "Execute one task with each page loaded. Use case: Single user instance." : "Mit jeder geladenen Seite wird eine Aufgabe ausgeführt. Anwendungsfall: Einzelbenutzer-Installation.",
    "Webcron" : "Webcron",
    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php ist bei einem Webcron-Dienst registriert, um cron.php alle 5 Minuten über HTTP aufzurufen. Anwendungsfall: Sehr kleine Instanz (1–5 Benutzer je nach Nutzung).",
    "Cron (Recommended)" : "Cron (Empfohlen)",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Um dies auszuführen, wird die PHP-Posix-Erweiterung benötigt. Weitere Informationen finden Sie in der {linkstart}PHP-Dokumentation{linkend}. ",
    "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "Verwenden Sie den System-Cron-Dienst, um die Datei cron.php alle 5 Minuten aufzurufen. Empfohlen für alle Installationen.",
    "The cron.php needs to be executed by the system user \"{user}\"." : "Die cron.php muss durch den Systembenutzer \"{user}\" ausgeführt werden.",
    "Unable to update background job mode" : "Hintergrund-Aufgaben-Modus kann nicht aktualisiert werden",
    "Profile" : "Profil",
    "Enable or disable profile by default for new users." : "Profil für neue Benutzer standardmäßig aktivieren oder deaktivieren.",
    "Enable" : "Aktivieren",
    "Unable to update profile default setting" : "Standardeinstellung des Profils kann nicht aktualisiert werden",
    "Server-side encryption" : "Serverseitige Verschlüsselung",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Serverseitige Verschlüsselung ermöglicht es die auf diesen Server hochgeladenen Dateien zu verschlüsseln. Dies führt allerdings auch zu Nachteilen, wie z.B. einem Geschwindigkeitsverlust. Sie sollte deshalb nur eingeschaltet werden, wenn sie wirklich benötigt wird.",
    "Enable server-side encryption" : "Serverseitige Verschlüsselung aktivieren",
    "Please read carefully before activating server-side encryption:" : "Bitte vor Aktivierung der serverseitigen Verschlüsselung sorgfältig lesen:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Wird die Verschlüsselung einmal aktiviert, so werden alle ab diesem Zeitpunkt hochgeladene Dateien verschlüsselt. Sie kann nur wieder deaktiviert werden, wenn das Verschlüsselungsmodul dies unterstützt und alle Voraussetzungen (wie das Setzen eines Wiederherstellungsschlüssels) im Vorhinein erfüllt wurden.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Verschlüsselung alleine garantiert nicht die Systemsicherheit. Bitte lese in der Dokumentation nach, wie die Verschlüsselungs-app funktioniert und welche Anwendungsfälle unterstützt werden.",
    "Be aware that encryption always increases the file size." : "Bedenken Sie, dass durch die Verschlüsselung die Dateigröße zunimmt. ",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Es ist immer gut, regelmäßig Sicherungskopien von ihren Daten zu machen. Falls Sie die Verschlüsselung nutzen, sollten Sie auch eine Sicherung der Verschlüsselungsschlüssel zusammen mit Ihren Daten machen.",
    "This is the final warning: Do you really want to enable encryption?" : "Dies ist die letzte Warnung: Möchten Sie die Verschlüsselung wirklich aktivieren?",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Es wurde kein Verschlüsselungs-Modul geladen, bitte ein Verschlüsselungs-Modul im Anwendungs-Menü aktivieren.",
    "Select default encryption module:" : "Standard-Verschlüsselungs-Modul auswählen:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "Sie müssen Ihre Verschlüsselungsschlüssel von der alten Verschlüsselung (ownCloud <= 8.0) auf die neue migrieren. Bitte aktivieren Sie das \"Standardverschlüsselungsmodul\" und führen den Befehl {command} aus",
    "Unable to update server side encryption config" : "Serverseitige Verschlüsselungskonfiguration kann nicht aktualisiert werden",
    "Rename group" : "Gruppe umbenennen",
    "Remove group" : "Gruppe entfernen",
    "You are about to remove the group {group}. The users will NOT be deleted." : "Sie sind im Begriff, die Gruppe {group} zu löschen. Die Benutzer werden NICHT gelöscht.",
    "Please confirm the group removal " : "Bitte die Löschung der Gruppe bestätigen",
    "Current password" : "Aktuelles Passwort",
    "New password" : "Neues Passwort",
    "Change password" : "Passwort ändern",
    "Your profile information" : "Ihre Profilinformation",
    "Your profile picture" : "Ihr Profilbild",
    "Upload profile picture" : "Profilbild hochladen",
    "Choose profile picture from Files" : "Profilbild aus Dateien wählen",
    "Remove profile picture" : "Profilbild entfernen",
    "The file must be a PNG or JPG" : "Die Datei muss im PNG- oder JPG-Format sein",
    "Picture provided by original account" : "Bild von Original-Konto zur Verfügung gestellt",
    "Cancel" : "Abbrechen",
    "Set as profile picture" : "Als Profilbild festlegen",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Bitte beachten, dass es bis zu 24 Stunden dauern kann, bis Ihr Profilbild überall aktualisiert ist.",
    "Choose your profile picture" : "Wählen Sie Ihr Profilbild aus.",
    "Please select a valid png or jpg file" : "Bitte eine gültige PNG- oder JPG-Datei auswählen",
    "Error setting profile picture" : "Fehler beim Einstellen des Profilbilds",
    "Error cropping profile picture" : "Fehler beim Zuschneiden des Profilbilds",
    "Error saving profile picture" : "Fehler beim Speichern des Profilbilds",
    "Error removing profile picture" : "Fehler beim Entfernen des Profilbilds",
    "Your biography" : "Ihre Biografie",
    "Details" : "Details",
    "You are a member of the following groups:" : "Sie sind Mitglied folgender Gruppen:",
    "You are using <strong>{usage}</strong>" : "Sie benutzen <strong>{usage}</strong>",
    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Sie benutzen <strong>{usage}</strong> von <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
    "Your full name" : "Ihr vollständiger Name",
    "Email options" : "E-Mail-Optionen",
    "Primary email for password reset and notifications" : "Primäre E-Mail-Adresse für Benachrichtigungen und Passwort-Zurücksetzen",
    "Remove primary email" : "Primäre E-Mail-Adresse entfernen",
    "Delete email" : "E-Mail löschen",
    "Unset as primary email" : "Als primäre E-Mail-Adresse deaktiviert",
    "This address is not confirmed" : "Diese Adresse ist nicht bestätigt",
    "Set as primary email" : "Als primäre E-Mail-Adresse festlegen",
    "Your email address" : "Ihre E-Mail-Adresse",
    "Additional email address {index}" : "Zusätzliche E-Mail-Adresse {index}",
    "Unable to delete primary email address" : "Primäre E-Mail-Adresse konnte nicht gelöscht werden",
    "Unable to update primary email address" : "Primäre E-Mail-Adresse konnte nicht aktualisiert werden",
    "Unable to add additional email address" : "Zusätzliche E-Mail-Adresse kann nicht hinzugefügt werden",
    "Unable to update additional email address" : "Zusätzliche E-Mail-Adresse konnte nicht aktualisiert werden",
    "Unable to delete additional email address" : "Zusätzliche E-Mail-Adresse konnte nicht gelöscht werden",
    "No email address set" : "Keine E-Mail-Adresse angegeben",
    "Additional emails" : "Zusätzliche E-Mail-Adressen",
    "Your handle" : "Dein Online-Name",
    "Your headline" : "Ihre Überschrift",
    "Language" : "Sprache",
    "Help translate" : "Helfen Sie bei der Übersetzung",
    "Unable to update language" : "Sprache konnte nicht aktualisiert werden",
    "No language set" : "Keine Sprache eingestellt",
    "Locale" : "Gebietsschema",
    "Week starts on {firstDayOfWeek}" : "Woche beginnt am {firstDayOfWeek}",
    "Unable to update locale" : "Gebietsschema kann nicht aktualisiert werden",
    "No locale set" : "Kein Gebietsschema festgelegt",
    "Your location" : "Ihr Ort",
    "Your organisation" : "Ihre Organisation",
    "Your phone number" : "Ihre Telefonnummer",
    "Edit your Profile visibility" : "Bearbeiten Sie die Sichtbarkeit Ihres Profils",
    "Enable Profile" : "Profil aktivieren",
    "Unable to update profile enabled state" : "Der Status für aktiviertes Profil konnte nicht aktualisiert werden",
    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "Die restriktivere Einstellung von Sichtbarkeit oder Bereich wird in Ihrem Profil berücksichtigt. Wenn beispielsweise die Sichtbarkeit auf \"Für alle anzeigen\" und der Bereich auf \"Privat\" festgelegt ist, wird \"Privat\" respektiert.",
    "Unable to update visibility of {displayId}" : "Sichtbarkeit von {displayId} kann nicht aktualisiert werden",
    "Your role" : "Ihre Funktion",
    "Your Twitter handle" : "Ihr Twitter-Handle",
    "Your website" : "Ihre Webseite",
    "No {property} set" : "Keine {property} gesetzt",
    "Unable to update {property}" : "{property} konnte nicht aktualisiert werden",
    "Change scope level of {property}, current scope is {scope}" : "Ändern des Geltungsbereich von {property}, aktueller Bereich ist {scope}",
    "Unable to update federation scope of the primary {property}" : "Der Federation-Bereich des primären  {property} kann nicht aktualisiert werden",
    "Unable to update federation scope of additional {property}" : "Der Federation-Bereich des zusätzlichen {property} kann nicht aktualisiert werden",
    "Add additional email" : "Zusätzliche E-Mail-Adresse hinzufügen",
    "Add" : "Hinzufügen",
    "You do not have permissions to see the details of this user" : "Sie haben keine Berechtigung, um auf die Details dieses Benutzers zu sehen",
    "Add new password" : "Neues Passwort hinzufügen",
    "Add new email address" : "Neue E-Mail-Adresse hinzufügen",
    "Add user to group" : "Benutzer der Gruppe hinzufügen",
    "Set user as admin for" : "Benutzer als Administrator setzen für",
    "Select user quota" : "Benutzerkontingent auswählen",
    "Delete user" : "Benutzer löschen",
    "Wipe all devices" : "Alle Geräte löschen",
    "Disable user" : "Benutzer deaktivieren",
    "Enable user" : "Benutzer aktivieren",
    "Resend welcome email" : "Willkommens-E-Mail erneut senden",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Im Falle des Verlusts des Gerätes oder des Verlassens der Organisation können mit dieser Funktion sämtliche Nextcloud-Daten von allen Geräten, die mit {userid} verbunden sind, gelöscht werden. Funktioniert nur, wenn das Gerät mit dem Internet verbunden ist.",
    "Remote wipe of devices" : "Fernlöschung von Geräten",
    "Wipe {userid}'s devices" : "Lösche {userid}s Geräte",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Lösche {userid}s Konto vollständig inklusive aller persönlichen Dateien, App-Daten, usw.",
    "Account deletion" : "Löschung des Kontos",
    "Delete {userid}'s account" : "Konto von {userid} löschen",
    "Welcome mail sent!" : "Willkommens-E-Mail gesendet!",
    "Edit User" : "Benutzer bearbeiten",
    "Toggle user actions menu" : "Menü für Benutzeraktionen umschalten",
    "{size} used" : "{size} verwendet",
    "New user" : "Neuer Benutzer",
    "Will be autogenerated" : "Wird automatisch erzeugt",
    "Display name" : "Anzeigename",
    "Email" : "E-Mail",
    "Default language" : "Standard-Sprache",
    "Add a new user" : "Neuen Benutzer hinzufügen",
    "Group admin for" : "Gruppenadministrator für",
    "Quota" : "Kontingent",
    "User backend" : "Benutzer-Backend",
    "Storage location" : "Speicherort",
    "Last login" : "Letzte Anmeldung",
    "No users in here" : "Keine Benutzer vorhanden",
    "Default quota" : "Standard Speicherkontingent ",
    "Common languages" : "Gebräuchliche Sprachen",
    "Other languages" : "Weitere Sprachen",
    "Password change is disabled because the master key is disabled" : "Das Ändern des Passwortes ist deaktiviert, da der Master-Schlüssel deaktiviert ist",
    "Passwordless authentication requires a secure connection." : "Die Anmeldung ohne Passwort erfordert eine sichere Verbindung.",
    "Add WebAuthn device" : "WebAuthn-Gerät hinzufügen",
    "Please authorize your WebAuthn device." : "Bitte autorisieren Sie Ihr WebAuthn-Gerät.",
    "Name your device" : "Gerät benennen",
    "Adding your device …" : "Fügen Sie Ihr Gerät hinzu…",
    "Server error while trying to add WebAuthn device" : "Server-Fehler beim Versuch ein WebAuthn-Gerät hinzuzufügen",
    "Server error while trying to complete WebAuthn device registration" : "Server-Fehler beim Versuch die WebAuthn-Geräte-Registrierung abzuschließen",
    "Unnamed device" : "Unbenanntes Gerät",
    "Passwordless Authentication" : "Authentifizierung ohne Passwort",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Richten Sie Ihr Konto für die Authentifizierung ohne Passwort nach dem FIDO2-Standard ein.",
    "No devices configured." : "Keine Geräte eingerichtet.",
    "The following devices are configured for your account:" : "Die folgenden Geräte sind für Ihr Konto eingerichtet:",
    "Your browser does not support WebAuthn." : "Ihr Browser unterstützt kein WebAuthn.",
    "Your apps" : "Ihre Apps",
    "{license}-licensed" : "{license}-Lizenziert",
    "Changelog" : "Liste der Änderungen",
    "by {author}\n{license}" : "von {author}\n{license}",
    "Enter group name" : "Gruppenname eingeben",
    "Add group" : "Gruppe hinzufügen",
    "Active users" : "Aktive Benutzer",
    "Admins" : "Administration",
    "Disabled users" : "Deaktivierte Benutzer",
    "Default quota:" : "Standardkontingent:",
    "Select default quota" : "Standardkontingent auswählen",
    "Show Languages" : "Sprachen anzeigen",
    "Show last login" : "Letzte Anmeldung anzeigen",
    "Show user backend" : "Benutzer-Backend anzeigen",
    "Show storage path" : "Zeige Speicherpfad",
    "Send email to new user" : "E-Mail an neuen Benutzer senden",
    "Not saved" : "Nicht gespeichert",
    "Sending…" : "Senden…",
    "Email sent" : "E-Mail gesendet",
    "Location" : "Ort",
    "Profile picture" : "Profilbild",
    "About" : "Über",
    "Full name" : "Vollständiger Name",
    "Additional email" : "Zusätzliche E-Mail-Adresse",
    "Headline" : "Überschrift",
    "Organisation" : "Organisation",
    "Phone number" : "Telefonnummer",
    "Role" : "Funktion",
    "Twitter" : "Twitter",
    "Fediverse (e.g. Mastodon)" : "Fediverse (wie z. B. Mastodon)",
    "Website" : "Webseite",
    "Profile visibility" : "Sichtbarkeit des Profils",
    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Nicht verfügbar, da diese Eigenschaft für Kernfunktionen wie Dateifreigabe und Kalendereinladungen erforderlich ist.",
    "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "Nicht verfügbar, da Föderation für Ihr Konto deaktiviert ist. Bitte wenden Sie sich an Ihre Administration, wenn Sie Fragen haben",
    "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Nicht verfügbar, da die Veröffentlichung benutzerspezifischer Daten auf dem Lookup-Server nicht zulässig ist. Wenden Sie sich bei Fragen an Ihre Systemadministration.",
    "Active apps" : "Aktive Apps",
    "Disabled apps" : "Deaktivierte Apps",
    "Updates" : "Aktualisierungen",
    "App bundles" : "App-Pakete",
    "Featured apps" : "Vorgestellte Apps",
    "Show to everyone" : "Jedem anzeigen",
    "Show to logged in users only" : "Nur angemeldeten Benutzern anzeigen",
    "Hide" : "Ausblenden",
    "Download and enable" : "Herunterladen und aktivieren",
    "Enable untested app" : "Ungetestete App aktivieren",
    "The app will be downloaded from the App Store" : "Die App wird aus dem App-Store heruntergeladen",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Diese App ist als nicht-kompatibel mit Ihrer Nextcloud-Version markiert. Wenn Sie fortfahren, so können Sie die App installieren. Bitte beachten Sie, dass die App nicht wie erwartet funktionieren könnte.",
    "Never" : "Niemals",
    "An error occurred during the request. Unable to proceed." : "Es ist ein Fehler bei der Anfrage aufgetreten. Es kann nicht fortgefahren werden.",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Die App wurde aktiviert, muss aber aktualisiert werden. Sie werden in 5 Sekunden zur Aktualisierungsseite weitergeleitet.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Fehler: Diese App kann nicht aktiviert werden, da sie den Server instabil macht. ",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Zu viele Anfragen aus Ihrem Netzwerk. Versuchen Sie es später erneut oder wenden Sie sich an Ihre Administration, wenn dies ein Fehler sein sollte.",
    "Documentation" : "Dokumentation",
    "Forum" : "Forum",
    "Login" : "Anmelden",
    "SSL/TLS" : "SSL/TLS",
    "Open documentation" : "Dokumentation öffnen",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Es ist wichtig diesen Server so zu konfigurieren, dass E-Mails versandt werden können, z.B. für den Passwort-Reset und Benachrichtigungen.",
    "Send mode" : "Sendemodus",
    "Encryption" : "Verschlüsselung",
    "Sendmail mode" : "Sendmail-Modus",
    "From address" : "Absenderadresse",
    "Server address" : "Serveradresse",
    "Port" : "Port",
    "Authentication method" : "Authentifizierungsmethode",
    "Only applies when authentication is required" : "Gilt nur, wenn eine Authentifizierung erforderlich ist",
    "Authentication required" : "Authentifizierung benötigt",
    "Credentials" : "Zugangsdaten",
    "SMTP Username" : "SMTP-Benutzername",
    "SMTP Password" : "SMTP-Passwort",
    "Save" : "Speichern",
    "Test and verify email settings" : "Testen und Überprüfen der E-Mail-Einstellungen",
    "Send email" : "E-Mail senden",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Für die Sicherheit und Geschwindigkeit Ihrer Installation ist es von großer Bedeutung, dass sie richtig konfiguriert ist. Um Ihnen hierbei zu helfen werden einige automatische Tests durchgeführt. Weitere Informationen finden Sie in der verlinkten Dokumentation.",
    "All checks passed." : "Alle Überprüfungen bestanden.",
    "There are some errors regarding your setup." : "Es gibt einige Fehler in Ihrer Systemkonfiguration.",
    "There are some warnings regarding your setup." : "Es gibt einige Warnungen zu Ihrer Systemkonfiguration.",
    "Checking for system and security issues." : "Prüfung auf System- und Sicherheitsprobleme.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Bitte überprüfen Sie noch einmal die <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">Installationsanleitungen ↗</a> und kontrollieren Sie das <a href=\"%2$s\">Protokoll</a> auf mögliche Fehler oder Warnungen.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Überprüfen Sie die Sicherheit Ihrer Nextcloud mit unserem <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">Sicherheits-Scan ↗</a>.",
    "Version" : "Version",
    "You need to enable the File sharing App." : "Sie müssen die App \"File sharing\" aktivieren.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Als Administrator können sie das Teilen-Verhalten feinabstimmen. Weitere Informationen finden Sie in der Dokumentation.",
    "Allow apps to use the Share API" : "Apps die Benutzung der Share-API erlauben",
    "Set default expiration date for shares" : "Legen Sie das Standardablaufdatum für Freigaben fest",
    "Expire after" : "Ablauf nach",
    "day(s)" : "Tag(e)",
    "Enforce expiration date" : "Ablaufdatum erzwingen",
    "Set default expiration date for shares to other servers" : "Standardablaufdatum für Freigaben an andere Server festlegen",
    "Allow users to share via link and emails" : "Benutzern erlauben, Inhalte über Links und E-Mails zu teilen.",
    "Allow public uploads" : "Öffentliches Hochladen erlauben",
    "Always ask for a password" : "Immer nach einem Passwort fragen",
    "Enforce password protection" : "Passwortschutz erzwingen",
    "Exclude groups from password requirements:" : "Gruppen vom Passwortvorschriften ausschließen:",
    "Set default expiration date" : "Standardmäßiges Ablaufdatum setzen",
    "Exclude groups from creating link shares:" : "Gruppen von der Erstellung von Link-Freigaben ausschließen:",
    "Allow resharing" : "Weiterteilen erlauben",
    "Allow sharing with groups" : "Teilen mit Gruppen erlauben",
    "Restrict users to only share with users in their groups" : "Benutzer auf das Teilen innerhalb ihrer Gruppen beschränken",
    "Exclude groups from sharing" : "Gruppen von Freigaben ausschließen",
    "These groups will still be able to receive shares, but not to initiate them." : "Diese Gruppen können weiterhin Freigaben empfangen, aber selbst keine mehr initiieren.",
    "Allow username autocompletion in share dialog" : "Automatische Vervollständigung der Benutzernamen im Teilen-Dialog erlauben",
    "Allow username autocompletion to users within the same groups" : "Automatische Vervollständigung der Benutzernamen auf Benutzer innerhalb der gleichen Gruppen erlauben",
    "Allow username autocompletion to users based on phone number integration" : "Automatische Vervollständigung des Benutzernamens für Benutzer basierend auf der Rufnummernintegration zulassen",
    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Wenn die Autovervollständigung \"gleiche Gruppe\" und \"Rufnummernintegration\" aktiviert ist, reicht eine Übereinstimmung in einem der beiden Bereiche aus, um den Benutzer anzuzeigen.",
    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Ermöglicht die automatische Vervollständigung, wenn der volle Namen oder E-Mail-Adresse eingegeben wird (ignoriert fehlende Telefonbuchübereinstimmungen und gleiche Gruppenzugehörigkeit)",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Haftungsausschluss auf der öffentlichen Upload-Seite anzeigen (Wird nur gezeigt, wenn die Dateiliste nicht angezeigt wird.) ",
    "This text will be shown on the public link upload page when the file list is hidden." : "Dieser Text wird auf der öffentlichen Upload-Seite angezeigt wenn die Dateiliste nicht angezeigt wird.",
    "Default share permissions" : "Standardberechtigungen für das Teilen",
    "Reasons to use Nextcloud in your organization" : "Gründe für die Verwendung von Nextcloud in Ihrer Organisation",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Entwickelt von der {communityopen}Nextcloud Community{linkclose}, der {githubopen}Quellcode{linkclose} ist lizensiert unter {licenseopen}AGPL{linkclose}-Lizenz.",
    "Like our Facebook page" : "Liken Sie uns auf unserer Facebook-Seite",
    "Follow us on Twitter" : "Folgen Sie uns auf Twitter",
    "Follow us on Mastodon" : "Folgen Sie uns auf Mastodon",
    "Check out our blog" : "Sehen Sie sich unseren Blog an",
    "Subscribe to our newsletter" : "Abonnieren Sie unseren Newsletter",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Diese Community-Version von Nextcloud wird nicht unterstützt und sofortige Benachrichtigungen sind nicht verfügbar. ",
    "Use a second factor besides your password to increase security for your account." : "Verwenden Sie neben Ihrem Passwort einen zweiten Faktor, um die Sicherheit für Ihr Konto zu erhöhen.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Wenn Sie Anwendungen von Drittanbietern verwenden, um sich mit Nextcloud zu verbinden, stellen Sie bitte sicher, dass Sie für jede Anwendung ein Anwendungspasswort erstellen und konfigurieren, bevor Sie die Zwei-Faktor-Authentifizierung aktivieren.",
    "An error occurred while changing your language. Please reload the page and try again." : "Es ist ein Fehler beim Wechseln der Sprache aufgetreten. Bitte laden Sie die Seite neu und versuchen es noch einmal.",
    "An error occurred while changing your locale. Please reload the page and try again." : "Es ist ein Fehler beim Wechseln des Gebietsschemas aufgetreten. Bitte laden Sie die Seite neu und versuchen es noch einmal.",
    "Select a profile picture" : "Wählen Sie ein Profilbild",
    "Week starts on {fdow}" : "Die Woche startet am {fdow}",
    "You created app password \"{token}\"" : "Sie haben das App-Passwort \"{token}\" erstellt",
    "An administrator created app password \"{token}\"" : "Ein vom Administrator erstelltes App-Passwort \"{token}\"",
    "Couldn't remove app." : "Die App konnte nicht entfernt werden.",
    "Couldn't update app." : "Die App konnte nicht aktualisiert werden.",
    "Backend doesn't support password change, but the user's encryption key was updated." : "Das Backend unterstützt die Passwortänderung nicht, aber das Verschlüsselungspasswort des Benutzers wurde aktualisiert.",
    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the nextcloud log file for more details." : "Es konnte nicht festgestellt werden, ob die TLS-Version von cURL veraltet ist oder nicht, da während der HTTPS-Anforderung an https://nextcloud.com ein Fehler aufgetreten ist. Bitte überprüfen Sie die Nextcloud-Protokolldatei für weitere Einzelheiten.",
    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "Die maximale Anzahl von OPcache-Schlüsseln ist fast überschritten. Um sicherzustellen, dass alle Skripte im Cache gehalten werden können, wird empfohlen, <code>opcache.max_accelerated_files</code> mit einem höheren Wert als <code>%s</code> auf Ihre PHP-Konfiguration anzuwenden.",
    "Admin privileges" : "Administratorrechte",
    "Unable to update biography" : "Biografie konnte nicht aktualisiert werden",
    "Unable to update full name" : "Der vollständige Name konnte nicht aktualisiert werden",
    "No full name set" : "Kein vollständiger Name festgelegt",
    "Unable to update headline" : "Überschrift konnte nicht aktualisiert werden",
    "Unable to update organisation" : "Organisation konnte nicht aktualisiert werden",
    "Unable to update role" : "Rolle konnte nicht aktualisiert werden",
    "Change scope level of {accountProperty}" : "Geltungsbereich von {accountProperty} ändern",
    "Unable to update federation scope of the primary {accountProperty}" : "Der Federation-Bereich des primären {accountProperty} kann nicht aktualisiert werden",
    "Unable to update federation scope of additional {accountProperty}" : "Der Federation-Bereich des zusätzlichen {accountProperty} kann nicht aktualisiert werden",
    "Migration in progress. Please wait until the migration is finished" : "Migration läuft. Bitte warte, bis die Migration abgeschlossen ist",
    "Migration started …" : "Migration begonnen…",
    "Address" : "Adresse",
    "Avatar" : "Avatar",
    "An error occured during the request. Unable to proceed." : "Es ist ein Fehler bei der Anfrage aufgetreten. Es kann nicht fortgefahren werden.",
    "Plain" : "Klartext",
    "NT LAN Manager" : "NT-LAN-Manager",
    "STARTTLS" : "STARTTLS",
    "Please read carefully before activating server-side encryption: " : "Bitte sorgfältig lesen, bevor die serverseitige Verschlüsselung aktiviert wird:",
    "Enable encryption" : "Verschlüsselung aktivieren",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Sie müssen Ihre Verschlüsselungsschlüssel von der alten Verschlüsselung (ownCloud <= 8.0) zur Neuen migrieren. Bitte aktivieren Sie das \"Default Encryption Module\" und rufen Sie 'occ encryption:migrate' auf.",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Sie müssen Ihre Verschlüsselungsschlüssel von der alten Verschlüsselung (ownCloud <= 8.0) zur Neuen migrieren.",
    "Start migration" : "Migration beginnen",
    "Last job execution ran %s. Something seems wrong." : "Letzte Aufgaben-Ausführung lief %s. Etwas scheint falsch zu sein.",
    "Some jobs haven’t been executed since %s. Please consider increasing the execution frequency." : "Einige Aufträge wurden seit %s nicht mehr ausgeführt. Bitte erwägen Sie, die Ausführungsfrequenz zu erhöhen.",
    "Some jobs didn’t execute since %s. Please consider switching to system cron." : "Einige Aufträge wurden seit %s nicht mehr ausgeführt. Bitte erwägen Sie die Umstellung auf System-Cron.",
    "Last job ran %s." : "Letzte Aufgabe ausgeführt %s",
    "Background job didn’t run yet!" : "Hintergrund-Aufgabe wurde bislang nicht ausgeführt!",
    "For the server to work properly, it's important to configure background jobs correctly. \"Cron\" is the recommended setting. Please see the documentation for more information." : "Damit der Server ordnungsgemäß funktioniert, ist es wichtig, Hintergrundjobs richtig zu konfigurieren. \"Cron\" ist die empfohlene Einstellung. Weitere Informationen finden Sie in der Dokumentation.",
    "Pick background job setting" : "Einstellung für Hintergrund-Aufgaben auswählen",
    "Recommended" : "Empfohlen",
    "The cron.php needs to be executed by the system user \"%s\"." : "Die cron.php muss durch den Systemnutzer \"%s\" ausgeführt werden.",
    "Change privacy level of profile picture" : "Datenschutzstufe des Profilbildes ändern",
    "Upload new" : "Neues hochladen",
    "Select from Files" : "Aus Dateien wählen",
    "Remove image" : "Bild entfernen",
    "png or jpg, max. 20 MB" : "png oder jpg, max. 20 MB",
    "Please note that it can take up to 24 hours for the avatar to get updated everywhere." : "Bitte beachten Sie, dass es bis zu 24 Stunden dauern kann, bis der Avatar überall aktualisiert wird.",
    "Choose as profile picture" : "Als Profilbild auswählen",
    "You are using <strong>%s</strong>" : "Sie benutzen <strong>%s</strong>",
    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Sie verwenden <strong>%1$s</strong> von <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
    "Change privacy level of phone number" : "Datenschutzstufe der Telefonnummer ändern",
    "Change privacy level of address" : "Datenschutzstufe der Adresse ändern",
    "Your postal address" : "Ihre Postadresse",
    "Change privacy level of website" : "Datenschutzstufe der Webseite ändern",
    "It can take up to 24 hours before the account is displayed as verified." : "Es kann bis zu 24 Stunden dauern, bis das Konto als überprüt angezeigt wird.",
    "Link https://…" : "Link https://…",
    "Change privacy level of Twitter profile" : "Datenschutzstufe des Twitter-Profils ändern",
    "Twitter handle @…" : "Twitter-Handle @…",
    "Choose profile picture from files" : "Profilbild aus Dateien auswählen"
},
"nplurals=2; plural=(n != 1);");
